{% extends 'utilities/obj_edit.html' %}
{% load form_helpers %}

{% block form %}
    <div class="panel panel-default">
        <div class="panel-heading"><strong>Device Work Log</strong></div>
        <div class="panel-body">
            {% render_field form.subject %}
            {% render_field form.category %}
            {% render_field form.internal_only %}
            {% render_field form.content %}
            {% render_field form.ticket_id %}
        </div>
    </div>
{% endblock %}