{% if perms.dcim.view_device %}
    <a href="{% url 'plugins:netbox_work_logs:deviceworklog_list' device=object.id%}" class="btn btn-info">
        <span class="fa fa-list" aria-hidden="true"></span> Device Work Logs
    </a>
{% endif %}