{% extends 'base.html' %}
{% load helpers %}

{% block title %}{% if obj %}{{ obj }}{% else %}{{ block.super }}{% endif %} - Work Logs{% endblock %}
{% block header %}
<div class="row noprint">
    <div class="col-sm-12 col-md-12">
        <ol class="breadcrumb">
            <li><a href="{{ obj.get_absolute_url }}">{{ obj }}</a></li>
            <li>Work Logs</li>
        </ol>
    </div>
</div>
{% endblock %}
{% block content %}
    <h1>{% if obj %}{{ obj }}{% endif %} - Work Logs</h1>
    <div class="row">
        <div class="col-md-{% if filter_form %}9{% else %}12{% endif %}">
            {% if permissions.change or permissions.delete %}
                <form method="POST" class="form form-horizontal">
                    {% csrf_token %}
                    <input type="hidden" name="return_url" value="{% if return_url %}{{ return_url }}{% else %}{{ request.path }}
                    {% if request.GET %}?{{ request.GET.urlencode }}{% endif %}{% endif %}">
                </form>
            {% else %}
                {% include table_template|default:'responsive_table.html' %}
            {% endif %}
            {% include 'inc/paginator.html' with paginator=table.paginator page=table.page %}
            <div class="clearfix"></div>
        </div>
        
        {% if filter_form %}
            <div class="col-md-3 noprint">
                {% include 'inc/search_panel.html' %}
                {% block sidebar %}{% endblock %}
            </div>
        {% endif %}
    </div>
    <!--
    {% include 'panel_table.html' %}
    {% include 'inc/paginator.html' with paginator=table.paginator page=table.page %}
    -->
{% endblock %}
